@@ -1,7 +1,7 @@
 # load credentials
 import logging
 import utils
-from utils import safe_read_simple_url, safe_get_json
+from utils import safe_read_simple_url, safe_get_json, safe_put_simple_url
 import os
 
 """
@@ -18,8 +18,12 @@ def getAwsInstanceDetails(config, authentication_token, account_id, host, log, d
                             'spectrum_dimensions': ['instance_id'],
                             'authentication_token': 'DUMMY-TOKEN',
                             'host': 'host-123'}
+    
+    metadata_token_url = config.get('aws_metadata_service_token_url', None)
+    aws_token = _fetch_aws_metadata_token(metadata_token_url, log=log)
+
     locator_url = config['aws_instance_id_locator_url']
-    instance_id = getAwsInstanceId(locator_url, log)
+    instance_id = getAwsInstanceId(locator_url, log, token=aws_token)
     if instance_id and authentication_token:
         instance_details = {'cloud_provider': 'AWS', 'instance_id': instance_id,
                             'authentication_token': authentication_token,
@@ -137,11 +141,18 @@ def init__configuration(config, cloud_provider, debug=False):
     return instance_details
 
 
-def getAwsInstanceId(locator_url, log):
+def getAwsInstanceId(locator_url, log, token=None):
     response = None
     if locator_url:
         if locator_url.startswith("http://"):
-            response = safe_read_simple_url(locator_url, log)
+            headers = {}
+
+            if token:
+                headers['x-aws-ec2-metadata-token'] = token
+            else:
+                log.warn("Failed to retrieve aws token, using IMDSv1 instead")
+
+            response = safe_read_simple_url(locator_url, log, headers=headers)
             response = str(response)
 
         else:
@@ -156,6 +167,22 @@ def getAwsInstanceId(locator_url, log):
     return response
 
 
+def _fetch_aws_metadata_token(token_url, log=logging.getLogger('spotinst-agent'), token_ttl=21600):
+    response = None
+
+    if token_url:
+        headers = {
+            'x-aws-ec2-metadata-token-ttl-seconds': str(token_ttl),
+        }
+
+        token_response = safe_put_simple_url(token_url, log, headers)
+
+        if token_response:
+            response = str(token_response)
+
+    return response
+
+
 def getGcpInstanceMetadata(locator_url, path_params, log):
     response = None
     if locator_url:
