@@ -71,6 +71,9 @@ install() {
 			lsb_dist='debian'
 		fi
 	fi
+	if [ -z "$lsb_dist" ] && [ -r /etc/fedora-release ]; then
+		lsb_dist='fedora'
+	fi
 	if [ -z "$lsb_dist" ] && [ -r /etc/centos-release ]; then
 		lsb_dist='centos'
 	fi
@@ -80,9 +83,6 @@ install() {
 	if [ -z "$lsb_dist" ] && [ -r /etc/SuSE-release ]; then
 		lsb_dist='suse'
 	fi
-	if [ -z "$lsb_dist" ] && [ -r /etc/fedora-release ]; then
-		lsb_dist='fedora'
-	fi
 	if [ -z "$lsb_dist" ] && [ -r /etc/system-release ]; then
 		os=`cat /etc/system-release | awk -F ' ' {'print $1'}`
 
@@ -175,7 +175,7 @@ validate() {
     architecture=$(uname -m)
 	case $architecture in
 		# officially supported
-		amd64|x86_64)
+		amd64|x86_64|aarch64)
 			;;
 		# not supported
 		*)
